.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. Description of using Gnuplot TotalDepth.util.gnuplot

.. _TotalDepth-tech-gnuplot:

*********************************************************************
Performance Graphs via Gnuplot with :py:mod:`TotalDepth.util.gnuplot`
*********************************************************************




